# Tonik

Tonik provides you with a solution to store and retrieve scientific data as well as serving it through an API.
For visualisations, the API can serve large requests very quickly by downsampling the data to the requested resolution on demand.

## Requirements
* h5py
* datashader
* xarray
* pandas
* netcdf4
* h5netcdf
* python-json-logger
* uvicorn
* fastapi

## Installation
```
pip install -U tonik
```

## Documentation

Learn more about tonik in its official [documentation](https://tsc-tools.github.io/tonik.github.io/)
Try out an [interactive Jupyter notebook](https://github.com/tsc-tools/tonik/tree/main/examples)

## Contributing

You can find information about contributing to tonik at our [Contributing page]

## Get in touch

Report bugs, suggest features, view the source code, and ask questions [on GitHub](https://github.com/tsc-tools/tonik).